==> jc-1.4.0.tar.gz: java/io/SequenceInputStream.h <==
// public class java.io.SequenceInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 4964cee224422733 java_io_SequenceInputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_java_io_SequenceInputStream_H_
#define _JC_java_io_SequenceInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_io_SequenceInputStream$sub_refs	_jc_java_io_SequenceInputStream$sub_refs;
typedef struct _jc_java_io_SequenceInputStream$sub_nonrefs	_jc_java_io_SequenceInputStream$sub_nonrefs;
typedef struct _jc_java_io_SequenceInputStream$refs	_jc_java_io_SequenceInputStream$refs;
typedef struct _jc_java_io_SequenceInputStream$nonrefs	_jc_java_io_SequenceInputStream$nonrefs;
typedef struct _jc_java_io_SequenceInputStream$object	_jc_java_io_SequenceInputStream$object;

typedef const struct _jc_java_io_SequenceInputStream$vmethods	_jc_java_io_SequenceInputStream$vmethods;
typedef const struct _jc_java_io_SequenceInputStream$vtable	_jc_java_io_SequenceInputStream$vtable;
typedef const struct _jc_java_io_SequenceInputStream$vtype	_jc_java_io_SequenceInputStream$vtype;

// Constructors
extern void _jc_java_io_SequenceInputStream$method$_init$3f374e9dc948638a(_jc_env *, struct _jc_java_io_SequenceInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_io_InputStream$object *);
extern void _jc_java_io_SequenceInputStream$method$_init$ecb31ef40e820156(_jc_env *, struct _jc_java_io_SequenceInputStream$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_java_io_SequenceInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_io_SequenceInputStream$object *);
extern void _jc_java_io_SequenceInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_SequenceInputStream$object *);
extern struct _jc_java_io_InputStream$object *_jc_java_io_SequenceInputStream$method$getNextStream$08f098e371c1ded1(_jc_env *, struct _jc_java_io_SequenceInputStream$object *);
extern jint _jc_java_io_SequenceInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_SequenceInputStream$object *);
extern jint _jc_java_io_SequenceInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_io_SequenceInputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_io_SequenceInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_io_SequenceInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_SequenceInputStream$method_info$getNextStream$08f098e371c1ded1;
extern _jc_method _jc_java_io_SequenceInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_SequenceInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_java_io_SequenceInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *);
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *);
	struct _jc_java_io_InputStream$object	*(*getNextStream$08f098e371c1ded1)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *, struct _jc_byte_array *, jint, jint);
};

// Vtable
struct _jc_java_io_SequenceInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_SequenceInputStream$vmethods	java_io_SequenceInputStream;
};

// Vtype
struct _jc_java_io_SequenceInputStream$vtype {
	_jc_type			type;
	_jc_java_io_SequenceInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_SequenceInputStream$sub_refs {
	struct _jc_java_io_InputStream$object	*in;
	struct _jc_java_io_InputStream$object	*in2;
	struct _jc_object	*e;
};

// Reference instance fields (object)
struct _jc_java_io_SequenceInputStream$refs {
    _jc_java_io_SequenceInputStream$sub_refs	java_io_SequenceInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_SequenceInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_SequenceInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_SequenceInputStream$sub_nonrefs	java_io_SequenceInputStream;
};

// Object instance structure
struct _jc_java_io_SequenceInputStream$object {
	_jc_java_io_SequenceInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_SequenceInputStream$vtype	*vtype;
	_jc_java_io_SequenceInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_SequenceInputStream$vtype _jc_java_io_SequenceInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_SequenceInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_SequenceInputStream$class_object;

#endif	/* _JC_java_io_SequenceInputStream_H_ */

==> jc-1.4.6.tar.gz: java/io/SequenceInputStream.h <==
// public class java.io.SequenceInputStream

// class file dependencies
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 4964cee224422733 java_io_SequenceInputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_java_io_SequenceInputStream_H_
#define _JC_java_io_SequenceInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_io_SequenceInputStream$sub_refs	_jc_java_io_SequenceInputStream$sub_refs;
typedef struct _jc_java_io_SequenceInputStream$sub_nonrefs	_jc_java_io_SequenceInputStream$sub_nonrefs;
typedef struct _jc_java_io_SequenceInputStream$refs	_jc_java_io_SequenceInputStream$refs;
typedef struct _jc_java_io_SequenceInputStream$nonrefs	_jc_java_io_SequenceInputStream$nonrefs;
typedef struct _jc_java_io_SequenceInputStream$object	_jc_java_io_SequenceInputStream$object;

typedef const struct _jc_java_io_SequenceInputStream$vmethods	_jc_java_io_SequenceInputStream$vmethods;
typedef const struct _jc_java_io_SequenceInputStream$vtable	_jc_java_io_SequenceInputStream$vtable;
typedef const struct _jc_java_io_SequenceInputStream$vtype	_jc_java_io_SequenceInputStream$vtype;

// Constructors
extern void _jc_java_io_SequenceInputStream$method$_init$3f374e9dc948638a(_jc_env *, struct _jc_java_io_SequenceInputStream$object *, struct _jc_java_io_InputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_SequenceInputStream$method$_init$ecb31ef40e820156(_jc_env *, struct _jc_java_io_SequenceInputStream$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_io_SequenceInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_io_SequenceInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_SequenceInputStream$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_SequenceInputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_java_io_SequenceInputStream$method$getNextStream$08f098e371c1ded1(_jc_env *, struct _jc_java_io_SequenceInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_SequenceInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_SequenceInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_SequenceInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_io_SequenceInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_SequenceInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_io_SequenceInputStream$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_SequenceInputStream$method_info$getNextStream$08f098e371c1ded1;
extern _jc_method _jc_java_io_SequenceInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_SequenceInputStream$method_info$read$e6b6c87b9f256783;

// Virtual methods structure
struct _jc_java_io_SequenceInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *) _JC_JCNI_ATTR;
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_InputStream$object	*(*getNextStream$08f098e371c1ded1)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_io_SequenceInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_SequenceInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_SequenceInputStream$vmethods	java_io_SequenceInputStream;
};

// Vtype
struct _jc_java_io_SequenceInputStream$vtype {
	_jc_type			type;
	_jc_java_io_SequenceInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_SequenceInputStream$sub_refs {
	struct _jc_java_io_InputStream$object	*in;
	struct _jc_java_io_InputStream$object	*in2;
	struct _jc_object	*e;
};

// Reference instance fields (object)
struct _jc_java_io_SequenceInputStream$refs {
    _jc_java_io_SequenceInputStream$sub_refs	java_io_SequenceInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_SequenceInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_SequenceInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_SequenceInputStream$sub_nonrefs	java_io_SequenceInputStream;
};

// Object instance structure
struct _jc_java_io_SequenceInputStream$object {
	_jc_java_io_SequenceInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_SequenceInputStream$vtype	*vtype;
	_jc_java_io_SequenceInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_SequenceInputStream$vtype _jc_java_io_SequenceInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_SequenceInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_SequenceInputStream$class_object;

#endif	/* _JC_java_io_SequenceInputStream_H_ */
